@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: tiny.cpp,v 1.11 1999/03/16 18:27:48 alstrup Exp $
+// $Id: tiny.cpp,v 1.12 1999/10/19 00:39:16 trow Exp $
 
 /* tiny.cpp
  *
@@ -25,22 +25,38 @@
 
 #include <config.h>
 #include <iostream>
-#include "RealSet.h"
+#include <Random.h>
+#include <RealSet.h>
+#include <runs.h>
 
-int main()
+
+main()
 {
-  RealSet ds;
-  for(int i=1; i<=10; ++i) {
-    ds.add(i);
-    ds.add(i);
-  }
+  
+  Random rng;
+  int abbr=0;
+  const int N = 20000;
 
-  for(int i=-1; i<12; ++i)
-    cout << i << " " << ds.less_than(i) << " " << ds.greater_than(i) << " " << ds.equal_to(i) << endl;
-  return 0;
+  for(int j=0; j<N; ++j) {
+
+    RunsCount r;
+    for(int i=0; i<20; ++i) {
+      r.add(rng.random_bool());
+    }
+
+    if (r.p_approx() < 0.05)
+      ++abbr;
+
+    if (j % 1000 == 0)
+      cout << j << endl;
+  }
+  double p = abbr/(double)N;
+  double sd = sqrt(p*(1-p)/N);
+  cout << endl << p-2*sd << " " << p << " " << p+2*sd << endl;
+    
 }
 
 
 
 
-// $Id: tiny.cpp,v 1.11 1999/03/16 18:27:48 alstrup Exp $
+// $Id: tiny.cpp,v 1.12 1999/10/19 00:39:16 trow Exp $
