@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: DataSet.cpp,v 1.3 1999/03/30 00:43:47 hp Exp $
+// $Id: DataSet.cpp,v 1.6 1999/07/20 21:20:04 trow Exp $
 
 /* 
  * DataSet.cpp
@@ -27,15 +27,16 @@
 
 #include "DataSet.h"
 
+int DataSet::default_offset_ = 0;
 const DataSet::type_t DataSet::invalid_typecode = 0x0;
 
 // Useful for debugging
 void DataSet::spew(ostream& out, char sep) const {
-  size_t const N = size();
-  for(size_t i=0; i<N; ++i)
+  int i0 = min_index(), i1 = max_index();
+  for(int i=i0; i<=i1; ++i)
     out << as_string(i) << sep;
   if (sep != '\n') out << endl;
 }
 
 
-// $Id: DataSet.cpp,v 1.3 1999/03/30 00:43:47 hp Exp $
+// $Id: DataSet.cpp,v 1.6 1999/07/20 21:20:04 trow Exp $
