@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: DateSet.h,v 1.8 1999/07/12 18:09:58 trow Exp $
+// $Id: DateSet.h,v 1.9 1999/07/15 17:43:42 trow Exp $
 
 /* 
  * DateSet.h
@@ -54,17 +54,17 @@ public:
     return new DateSet(*this);
   }
 
-  size_t size() const { return data_.size(); }
-  void reserve(size_t N) { data_.reserve(N); }
-  void resize(size_t N) { }
+  unsigned size() const { return data_.size(); }
+  void reserve(unsigned N) { data_.reserve(N); }
+  void resize(unsigned N) { }
 
   void add(GDate);
-  void add_at(size_t, GDate);
-  void set(size_t i, GDate);
-  GDate data(size_t i) const;
+  void add_at(int, GDate);
+  void set(int i, GDate);
+  GDate data(int i) const;
 
-  void remove(size_t i);
-  void remove(size_t begin, size_t end);
+  void remove(int i);
+  void remove(int begin, int end);
   void clear();
 
   void sort();
@@ -85,4 +85,4 @@ private:
 #endif
 #endif // _INC_DATESET_H
 
-// $Id: DateSet.h,v 1.8 1999/07/12 18:09:58 trow Exp $
+// $Id: DateSet.h,v 1.9 1999/07/15 17:43:42 trow Exp $
