@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: RealSet.cpp,v 1.11 1999/06/14 16:55:23 trow Exp $
+// $Id: RealSet.cpp,v 1.13 1999/07/20 20:52:09 trow Exp $
 
 /* 
  * RealSet.cpp
@@ -63,34 +63,36 @@ RealSet::sorted_data() const
 
   sdata_ = data_;
   double* s = sdata_.data();
+  const unsigned N = sdata_.size();
 
   if (sortedness() == 0) {
-    std::sort(s, s+sdata_.size(), less<double>());
+    std::sort(s, s+N, less<double>());
   } else if (sortedness() == -1) {
-    for(size_t i=0; i<size()/2; ++i) {
+    for(unsigned i=0; i<N/2; ++i) {
       double t = s[i];
-      s[i] = s[size()-1-i];
-      s[size()-1-i] = t;
+      s[i] = s[N-1-i];
+      s[N-1-i] = t;
     }
   }
 
   return (const double*)s;
 }
 
-size_t
+unsigned
 RealSet::greater_than(double x) const
 {
   if (size() == 0 || max() <= x) return 0;
   if (min() > x) return size();
 
   const double* d = sorted_data();
-  size_t i=0, j=size()-1;
+  const unsigned N = size();
+  unsigned i=0, j=N-1;
 
   for(;;) {
-    size_t mid=(i+j)/2;
-    if (mid == size()-1) --mid;
+    unsigned mid=(i+j)/2;
+    if (mid == N-1) --mid;
     if (d[mid] <= x && x < d[mid+1])
-      return size()-mid-1;
+      return N-mid-1;
     else if (d[mid] > x) 
       j = mid;
     else
@@ -98,18 +100,19 @@ RealSet::greater_than(double x) const
   }
 }
 
-size_t
+unsigned
 RealSet::less_than(double x) const
 {
   if (size() == 0 || min() >= x) return 0;
   if (max() < x) return size();
 
   const double* d = sorted_data();
-  size_t i=0, j=size()-1;
+  const unsigned N = size();
+  unsigned i=0, j=N-1;
 
   for(;;) {
-    size_t mid=(i+j)/2;
-    if (mid == size()-1) --mid;
+    unsigned mid=(i+j)/2;
+    if (mid == N-1) --mid;
     if (d[mid] < x && x <= d[mid+1])
       return mid+1;
     else if (d[mid] >= x)
@@ -120,13 +123,13 @@ RealSet::less_than(double x) const
 }
 
 void
-RealSet::reserve(size_t R)
+RealSet::reserve(unsigned R)
 {
   data_.reserve(R);
 }
 
 void
-RealSet::resize(size_t N)
+RealSet::resize(unsigned N)
 {
   if (size() > N) {
     remove(N, size());
@@ -148,13 +151,15 @@ RealSet::add(double x)
 }
 
 void
-RealSet::add_at(size_t i, double x)
+RealSet::add_at(int i, double x)
 {
-  if (i > size())
-    throw Exception("Index out of range");
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(i))
+    throw Exception_IndexOutOfBounds(i, min_index(), max_index());
+#endif
 
   update_add(x);
-  data_.add_at(i,x);
+  data_.add_at(i - min_index(),x);
   recalc_sortedness(); // sortedness will be wrong from update_add().
   if (sortedness_ > 0)
     sdata_ = data_;
@@ -163,13 +168,15 @@ RealSet::add_at(size_t i, double x)
 }
 
 void
-RealSet::remove(size_t i)
+RealSet::remove(int i)
 {
-  if (i > size())
-    throw Exception("Index out of range");
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(i))
+    throw Exception_IndexOutOfBounds(i, min_index(), max_index());
+#endif
 
   update_remove(data(i));
-  data_.remove_at(i);
+  data_.remove_at(i - min_index());
 
   // Remember, removing an element preserves sortedness.  The only possible
   // change is to bring an unsorted list into a sorted state.
@@ -189,51 +196,61 @@ RealSet::add(double* xs, size_t count)
   recalc();
 }
 void
-RealSet::add_at(size_t i, double* xs, size_t count)
+RealSet::add_at(int i, double* xs, size_t count)
 {
-  if (i > size())
-    throw Exception("Index out of range");
-  else if (i == size())
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(i))
+    throw Exception_IndexOutOfBounds(i,min_index(), max_index());
+#endif
+  if (i == max_index())
     add(xs, count);
   else {
-    data_.add_at(i,xs,count);
+    data_.add_at(i - min_index(),xs,count);
     recalc();
   }
 }
 
 void
-RealSet::remove(size_t i, size_t j)
+RealSet::remove(int i, int j)
 {
-  if (i > j) {
+  if (i > j)
     throw Exception("Illegal range");
-  }
-  if (j >= size()) {
-    throw Exception("Index out of range");
-  }
-  data_.remove_at(i,j);
+
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(j))
+    throw Exception_IndexOutOfBounds(j,min_index(),max_index());
+#endif
+
+  data_.remove_at(i-min_index(), j-min_index());
   recalc();
 }
 
 void
-RealSet::set(size_t i, double x)
+RealSet::set(int i, double x)
 {
-  if (i >= size()) {
-    throw Exception("Index out of range");
-  }
-  data_.data()[i] = x;
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(i))
+    throw Exception_IndexOutOfBounds(i,min_index(),max_index());
+#endif
+
+  data_.data()[i - min_index()] = x;
   recalc();
 }
 
 void
-RealSet::set(size_t i, const double* xs, size_t count)
+RealSet::set(int i, const double* xs, size_t count)
 {
-  if (i + count > size()) {
-    throw Exception("Index out of range");
-  }
+#ifdef REALSET_BOUNDS_CHECKING
+  if (! in_bounds(i))
+    throw Exception_IndexOutOfBounds(i,min_index(),max_index());
+  if (! in_bounds(i+count-1))
+    throw Exception_IndexOutOfBounds(i+count-1,min_index(),max_index());
+#endif
+    
   double* array = data_.data();
-  size_t j = 0;
+  unsigned j = 0;
   while (j < count) {
-    array[i+j] = xs[j];
+    array[i+j - min_index()] = xs[j];
     ++j;
   }
   recalc();
@@ -242,6 +259,7 @@ RealSet::set(size_t i, const double* xs, size_t count)
 void
 RealSet::clear()
 {
+  set_offset(0);
   data_.clear();
   sdata_.clear();
   mean_ = sumsq_ = 0;
@@ -255,9 +273,10 @@ RealSet::append(const RealSet& ds)
 
   // By saving N before we iterate, we should properly handle
   // the case where &ds == this.
-  size_t N = ds.size();
-  for(size_t i=0; i<N; ++i)
-    add(ds.data(i));
+  const double* d = ds.data();
+  const unsigned N = ds.size();
+  for(unsigned i=0; i<N; ++i)
+    add(d[i]);
 }
 
 /*
@@ -275,8 +294,9 @@ void
 RealSet::linear_transform(double a, double b)
 {
   double* d = data_.data();
+  const unsigned N = size();
 
-  for(size_t i=0; i<size(); ++i) 
+  for(unsigned i=0; i<N; ++i) 
     d[i] = a*d[i]+b;
 
   
@@ -292,15 +312,15 @@ RealSet::linear_transform(double a, double b)
   if (sdata_.size()) {
     double* s = sdata_.data();
     // linearly transform our sdata buffer
-    for(size_t i=0; i<size(); ++i)
+    for(unsigned i=0; i<N; ++i)
       s[i] = a*s[i]+b;
 
     // if a<0, reverse the sdata to preserve sortedness
     if (a<0) {
-      for(size_t i=0; i<size()/2; ++i) {
+      for(unsigned i=0; i<N/2; ++i) {
 	double t=s[i];
-	s[i]=s[size()-1-i];
-	s[size()-1-i]=t;
+	s[i]=s[N-1-i];
+	s[N-1-i]=t;
 	}
     }
   }
@@ -315,14 +335,14 @@ RealSet::log_transform()
     return;
   }
 
-  const size_t N = size();
+  const unsigned N = size();
   double* d = data_.data();
-  for (size_t i=0; i<N; ++i)
+  for (unsigned i=0; i<N; ++i)
     d[i] = log(d[i]);
 
   if (have_sorted_data()) {
     double* sd = sdata_.data();
-    for (size_t i=0; i<N; ++i)
+    for (unsigned i=0; i<N; ++i)
       sd[i] = log(sd[i]);
   }
 
@@ -332,14 +352,14 @@ RealSet::log_transform()
 void
 RealSet::exp_transform()
 {
-  const size_t N = size();
+  const unsigned N = size();
   double* d = data_.data();
-  for (size_t i=0; i<N; ++i)
+  for (unsigned i=0; i<N; ++i)
     d[i] = exp(d[i]);
 
   if (have_sorted_data()) {
     double* sd = sdata_.data();
-    for (size_t i=0; i<N; ++i)
+    for (unsigned i=0; i<N; ++i)
       sd[i] = exp(sd[i]);
   }
   
@@ -357,7 +377,8 @@ RealSet::logit_transform()
 
   // This could be optimized to preserve sorted data.
   double* d = data_.data();
-  for(size_t i=0; i<size(); ++i)
+  const unsigned N = size();
+  for(unsigned i=0; i<N; ++i)
     d[i] = log(d[i]/(1-d[i]));
 
   recalc();
@@ -372,9 +393,9 @@ RealSet::fabs_transform()
   if (max() <= 0) {
     linear_transform(-1, 0);
   } else if (min() < 0) {
-    const size_t N = size();
+    const unsigned N = size();
     double* d = data_.data();
-    for(size_t i=0; i<N; ++i)
+    for(unsigned i=0; i<N; ++i)
       d[i] = fabs(d[i]);
     recalc();
   }
@@ -384,7 +405,8 @@ void
 RealSet::deviations_transform(double y)
 {
   double* d = data_.data();
-  for(size_t i=0; i<size(); ++i)
+  const unsigned N = size();
+  for(unsigned i=0; i<N; ++i)
     d[i] = fabs(d[i]-y);
   recalc();
 }
@@ -395,11 +417,12 @@ RealSet::reverse()
   if (sortedness_ == 2) return;
 
   double* d = data_.data();
+  const unsigned N = size();
 
-  for(size_t i=0; i<size()/2; ++i) {
+  for(unsigned i=0; i<N/2; ++i) {
     double t = d[i];
-    d[i] = d[size()-i-1];
-    d[size()-1-i] = t;
+    d[i] = d[N-i-1];
+    d[N-1-i] = t;
   }
   sortedness_ = -sortedness_;
 }
@@ -466,20 +489,21 @@ RealSet::rank()
 {
   pair<double,int>* rankdata = new pair<double,int>[size()];
   double* d = data_.data();
+  const unsigned N = size();
 
-  for(size_t i1=0; i1<size(); ++i1) {
+  for(unsigned i1=0; i1<N; ++i1) {
     rankdata[i1].first = d[i1];
     rankdata[i1].second = i1;
   }
 
-  std::sort(rankdata, rankdata+size(), less< pair<double,int> >());
+  std::sort(rankdata, rankdata+N, less< pair<double,int> >());
 
   // set ranks, handling ties by the usual convention
   unsigned count=1;
-  for(size_t i=0; i<size(); /* increment down below */ ) {
-    size_t j=i+1;
+  for(unsigned i=0; i<N; /* increment down below */ ) {
+    unsigned j=i+1;
     unsigned count2=0;
-    while (j < size() && are_equal(rankdata[i].first, rankdata[j].first)) {
+    while (j < N && are_equal(rankdata[i].first, rankdata[j].first)) {
       ++j;
       ++count2;
     }
@@ -488,7 +512,7 @@ RealSet::rank()
     count += 1+count2;
   }
 
-  for(size_t i=0; i<size(); ++i)
+  for(unsigned i=0; i<N; ++i)
     d[rankdata[i].second] = rankdata[i].first;
 
   recalc(); // This could be optimized...
@@ -499,16 +523,15 @@ RealSet::rank()
 void
 RealSet::standardize()
 {
-  // This could be optimized to preserve sorted data.
-  double m = mean();
-  double s = sdev();
-  size_t N = size();
+  const double m = mean();
+  const double s = sdev();
+  const unsigned N = size();
   double* d = data_.data();
-  for(size_t i=0; i<N; ++i)
+  for(unsigned i=0; i<N; ++i)
     d[i] = (d[i]-m)/s;
   if (have_sorted_data()) {
     double* sd = sdata_.data();
-    for(size_t i=0; i<N; ++i)
+    for(unsigned i=0; i<N; ++i)
       sd[i] = (sd[i]-m)/s;
   }
   recalc_saving_sorted();
@@ -518,34 +541,35 @@ Permutation
 RealSet::sorting_permutation(int dir) const
 {
   Permutation p;
+  const unsigned N = size();
 
   if (sortedness_ == 2 ||
       (dir >= 0 && sortedness_ == 1) ||
       (dir < 0 && sortedness_ == -1)) {
 
-    p.set_identity(size());
+    p.set_identity(N);
 
   } else if ((dir > 0 && sortedness_ == -1) ||
 	     (dir < 0 && sortedness_ == 1)) {
 
-    p.set_reverse(size());
+    p.set_reverse(N);
 
   } else {
 
-    pair<double,size_t>* tmp = new pair<double,size_t>[size()];
-    size_t* tmp2 = new size_t[size()];
+    pair<double,unsigned>* tmp = new pair<double,unsigned>[N];
+    unsigned* tmp2 = new unsigned[N];
     const double* d = data_.data();
-    for (size_t i=0; i<size(); ++i) {
+    for (unsigned i=0; i<N; ++i) {
       tmp[i].first = d[i];
       tmp[i].second = i;
     }
 
     if (dir >= 0) 
-      std::sort(tmp, tmp+size(), less< pair<double,size_t> >());
+      std::sort(tmp, tmp+N, less< pair<double,unsigned> >());
     else
-      std::sort(tmp, tmp+size(), greater< pair<double,size_t> >());
+      std::sort(tmp, tmp+N, greater< pair<double,unsigned> >());
 
-    for(size_t i=0; i<size(); ++i)
+    for(unsigned i=0; i<N; ++i)
       tmp2[tmp[i].second] = i;
 
     p.initialize(size(), tmp2);
@@ -574,14 +598,14 @@ RealSet::write_xml(ostream& out, bool compress) const
   out << ">" << endl;
 
   const double* d = data_.data();
-  size_t N = size();
+  const unsigned N = size();
 
   if (compress) {
     // This is bigger than necessary.
     char buffer[16];
     memset(buffer,0,16);
 
-    for(size_t i=0; i<N; ++i) {
+    for(unsigned i=0; i<N; ++i) {
       encode_double(d[i], buffer);
       out << buffer;
       if (i % 7 == 6)
@@ -592,7 +616,7 @@ RealSet::write_xml(ostream& out, bool compress) const
   } else {
     int old_prec = out.precision();
     out.precision(17);
-    for(size_t i=0; i<N; ++i)
+    for(unsigned i=0; i<N; ++i)
       out << d[i] << endl;
     out.precision(old_prec);
   }
@@ -605,7 +629,7 @@ RealSet::update_add(double x)
 {
   // update statistics /////
 
-  size_t N = size();
+  const unsigned N = size();
 
   if (N == 0 || x < min_)
     min_ = x;
@@ -640,7 +664,7 @@ RealSet::update_add(double x)
 void
 RealSet::update_remove(double x)
 {
-  size_t N = size()-1;
+  const unsigned N = size()-1;
   double old_mean = mean_;
   mean_ += (mean_ - x)/N;
   if (N > 0)
@@ -648,7 +672,7 @@ RealSet::update_remove(double x)
 
   if (N != 0) {
     const double* d = data_.data_const();
-    size_t NN = size();
+    const unsigned NN = size();
     if (min_ == x) {
       bool skip_x = true;
       min_ = d[0];
@@ -656,7 +680,7 @@ RealSet::update_remove(double x)
 	min_ = d[1];
 	skip_x = false;
       }
-      for(size_t i=1; i<NN; ++i) {
+      for(unsigned i=1; i<NN; ++i) {
 	if (d[i] == x && skip_x) {
 	  skip_x = false;
 	  continue;
@@ -672,7 +696,7 @@ RealSet::update_remove(double x)
 	max_ = d[1];
 	skip_x = false;
       }
-      for(size_t i=1; i<NN; ++i) {
+      for(unsigned i=1; i<NN; ++i) {
 	if (d[i] == x && skip_x) {
 	  skip_x = false;
 	  continue;
@@ -694,9 +718,9 @@ RealSet::recalc_sortedness()
 {
   sortedness_ = 2;
   const double* d = data_.data_const();
-  size_t N = data_.size();
+  const unsigned N = data_.size();
 
-  for(size_t i=1; i<N && sortedness_; ++i) {
+  for(unsigned i=1; i<N && sortedness_; ++i) {
     double x = d[i];
     double prev = d[i-1];
     if (sortedness_ == 2) {
@@ -729,11 +753,11 @@ RealSet::recalc_saving_sorted()
   if (size() == 0) return;
 
   const double* d = data_.data_const();
-  size_t N = data_.size();
+  const unsigned N = data_.size();
 
   min_ = max_ = d[0];
   double old_mean;
-  for (size_t i=0; i<N; ++i) {
+  for (unsigned i=0; i<N; ++i) {
     double x = d[i];
     if (min_ > x) min_ = x;
     if (max_ < x) max_ = x;
@@ -781,5 +805,5 @@ RealSet::copy(const RealSet& ds)
 
 
 
-// $Id: RealSet.cpp,v 1.11 1999/06/14 16:55:23 trow Exp $
+// $Id: RealSet.cpp,v 1.13 1999/07/20 20:52:09 trow Exp $
 
