@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: RealSet.h,v 1.11 1999/06/14 16:55:24 trow Exp $
+// $Id: RealSet.h,v 1.13 1999/07/20 20:52:09 trow Exp $
 
 /* 
  * RealSet.h
@@ -27,6 +27,8 @@
 #ifndef _INC_REALSET_H
 #define _INC_REALSET_H
 
+#define REALSET_BOUNDS_CHECKING 1
+
 #include <math.h>
 #include <string>
 #include <iostream>
@@ -53,7 +55,7 @@ public:
     return new RealSet(*this);
   }
 
-  size_t size() const { return data_.size(); }
+  unsigned size() const { return data_.size(); }
   void empty_throw() const {
     if (size() == 0) throw Exception("RealSet is empty.");
   }
@@ -62,8 +64,8 @@ public:
       throw Exception("RealSets are not of the same size.");
   }
 
-  void reserve(size_t R); 
-  void resize(size_t N);
+  void reserve(unsigned R); 
+  void resize(unsigned N);
   void clear();
 
   // Return a permutation that will, when applied, bring the RealSet into
@@ -77,11 +79,22 @@ public:
 
   const double* data() const { return data_.data(); }
 
-  // note: no bounds checking
-  double data(size_t i) const { return (data_.data())[i]; } 
+  double data(int i) const { 
+#ifdef REALSET_BOUNDS_CHECKING
+    if (! in_bounds(i))
+      throw Exception_IndexOutOfBounds(i, min_index(), max_index());
+#endif
+    return (data_.data())[i - min_index()];
+  }
 
   const double* sorted_data() const;
-  double sorted_data(size_t i) const { return sorted_data()[i]; }
+  double sorted_data(int i) const {
+#ifdef REALSET_BOUNDS_CHECKING
+    if (i<0 || i >= (int)size())
+      throw Exception_IndexOutOfBounds(i, 0, size()-1);
+#endif
+    return sorted_data()[i];
+  }
 
   // You can get back garbage if you, for example, take the min() of
   // an empty dataset.
@@ -105,27 +118,27 @@ public:
   bool unordered() const { return sortedness_ == 0; }
   bool constant() const { return sortedness_ == 2; }
 
-  size_t greater_than(double x) const;
-  size_t less_than(double x) const ;
-  size_t between(double a, double b) const {
+  unsigned greater_than(double x) const;
+  unsigned less_than(double x) const ;
+  unsigned between(double a, double b) const {
     return size()-less_than(a)-greater_than(b);
   }
-  size_t equal_to(double x) const {
+  unsigned equal_to(double x) const {
     return size()-less_than(x)-greater_than(x);
   }
 
   // Implementation of typed interface inherited from DataSet_Typed
   void add(double);
   //  void add(string const & s) { DataSet_Typed<double>::add(s); }
-  void add_at(size_t i, double);
-  //  void add_at(size_t i, string const & s) { DataSet_Typed<double>::add_at(i, s); }
-  void set(size_t i, double);
-  void remove(size_t i);
-  void remove(size_t i, size_t j);
+  void add_at(int i, double);
+  //  void add_at(int i, string const & s) { DataSet_Typed<double>::add_at(i, s); }
+  void set(int i, double);
+  void remove(int i);
+  void remove(int i, int j);
 
   void add(double*, size_t count);
-  void add_at(size_t i, double*, size_t count);
-  void set(size_t i, const double*, size_t count);
+  void add_at(int i, double*, size_t count);
+  void set(int i, const double*, size_t count);
 
   void append(const RealSet&);
 
@@ -134,8 +147,10 @@ public:
 
   template<class FuncObj>
   void apply(FuncObj f) {
-    for(size_t i=0; i<size(); ++i)
-      (data_.data())[i] = f((data_.data())[i]);
+    double* d = data_.data();
+    unsigned N = size();
+    for(unsigned i=0; i<N; ++i)
+      d[i] = f(d[i]);
     recalc();
   }
 
@@ -159,8 +174,8 @@ public:
     same_size_throw(rs);
     double* d1 = data_.data();
     const double* d2 = rs.data_.data();
-    size_t N = size();
-    for(size_t i=0; i<N; ++i)
+    unsigned N = size();
+    for(unsigned i=0; i<N; ++i)
       d1[i] = f(d1[i],d2[i]);
     recalc();
     return *this;
@@ -246,4 +261,4 @@ private:
 
 #endif // _INC_REALSET_H
 
-// $Id: RealSet.h,v 1.11 1999/06/14 16:55:24 trow Exp $
+// $Id: RealSet.h,v 1.13 1999/07/20 20:52:09 trow Exp $
