@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: RealSet_smob.cpp,v 1.11 1999/07/09 19:45:15 trow Exp $
+// $Id: RealSet_smob.cpp,v 1.13 1999/07/15 19:01:54 trow Exp $
 
 /* 
  * RealSet_smob.cpp
@@ -499,6 +499,41 @@ GOOSE_PROC(gmeanthresh, "realset-gmean-threshold",
   return gh_double2scm(x);
 }
 
+GOOSE_PROC(meanthrperc, "realset-mean-threshold-percentage",
+	   2,0,0, (SCM scm_rs, SCM scm_c))
+{
+  SCM_ASSERT(REALSET_P(scm_rs), scm_rs, SCM_ARG1, str_meanthrperc);
+  SCM_ASSERT(gh_number_p(scm_c), scm_c, SCM_ARG2, str_meanthrperc);
+
+  double c = gh_scm2double(scm_c);
+  SCM_ASSERT(c >= 0 && c <= 1, scm_c, SCM_OUTOFRANGE, str_meanthrperc);
+  double x = 0;
+  try {
+    RealSet* rs = scm2realset(scm_rs);
+    x = goose_mean_threshold_percentage(*rs, c);
+  } GOOSE_CATCH(str_meanthrperc);
+
+  return gh_double2scm(x);
+}
+
+
+GOOSE_PROC(gmeanthrperc, "realset-gmean-threshold-percentage",
+	   2,0,0, (SCM scm_rs, SCM scm_c))
+{
+  SCM_ASSERT(REALSET_P(scm_rs), scm_rs, SCM_ARG1, str_gmeanthrperc);
+  SCM_ASSERT(gh_number_p(scm_c), scm_c, SCM_ARG2, str_gmeanthrperc);
+
+  double c = gh_scm2double(scm_c);
+  SCM_ASSERT(c >= 0 && c <= 1, scm_c, SCM_OUTOFRANGE, str_gmeanthrperc);
+  double x = 0;
+  try {
+    RealSet* rs = scm2realset(scm_rs);
+    x = goose_gmean_threshold_percentage(*rs, c);
+  } GOOSE_CATCH(str_gmeanthrperc);
+
+  return gh_double2scm(x);
+}
+
 GOOSE_PROC(covar, "realset-covar",
 	   2,0,0, (SCM scm_rs1, SCM scm_rs2))
 {
@@ -857,4 +892,4 @@ scm_init_realset()
 }
 
 
-// $Id: RealSet_smob.cpp,v 1.11 1999/07/09 19:45:15 trow Exp $
+// $Id: RealSet_smob.cpp,v 1.13 1999/07/15 19:01:54 trow Exp $
