@@ -1,4 +1,4 @@
-;;; $Id: RealSet_smob.scm,v 1.8 1999/07/09 19:51:51 trow Exp $
+;;; $Id: RealSet_smob.scm,v 1.9 1999/07/15 18:45:33 trow Exp $
 
 ;;; 
 ;;; RealSet_smob.scm
@@ -121,17 +121,5 @@
 (define (realset-%-less-than-or-equal-to rs x)
   (/ (realset-less-than-or-equal-to rs x) (realset-size rs)))
 
-;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(define (realset-gmean-threshold-percentile rs c)
-  (realset-%-greater-than rs (realset-gmean-threshold rs c)))
-	    
-
-
-
-
-
-
-
-
-;;; $Id: RealSet_smob.scm,v 1.8 1999/07/09 19:51:51 trow Exp $
+;;; $Id: RealSet_smob.scm,v 1.9 1999/07/15 18:45:33 trow Exp $
