@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: descriptive.cpp,v 1.12 1999/07/09 19:49:13 trow Exp $
+// $Id: descriptive.cpp,v 1.15 1999/07/20 08:34:27 alstrup Exp $
 
 /* descriptive.cpp
  *
@@ -26,6 +26,7 @@
 #include <config.h>
 #include <algorithm>
 #include <functional>
+#include <assert.h>
 #include "descriptive.h"
 
 double
@@ -442,6 +443,46 @@ goose_gmean_threshold(const RealSet& rs, double c)
   return guess;
 }
 
+double
+goose_mean_threshold_percentage(const RealSet& rs, double c)
+{
+  const unsigned N = rs.size();
+  const double* d = rs.sorted_data();
+  double goal = rs.sum() * c;
+  
+  unsigned count = 0;
+  double tally = 0;
+  while (count < N && tally <= goal) {
+    tally += d[count];
+    if (tally <= goal)
+      ++count;
+  }
+
+  return (N-count)/(double)N;
+}
+
+double
+goose_gmean_threshold_percentage(const RealSet& rs, double c)
+{
+  const unsigned N = rs.size();
+  const double* d = rs.sorted_data();
+
+  double goal = 0;
+  for(unsigned i=0; i<N; ++i)
+    goal += log(1+d[i]);
+  goal = log(c*exp(goal) - c + 1);
+
+  unsigned count = 0;
+  double tally = 0;
+  while (count < N && tally <= goal) {
+    tally += log(1+d[count]);
+    if (tally <= goal)
+      ++count;
+  }
+
+  return (N-count)/(double)N;
+}
+
 double
 goose_covar(const RealSet& rs0, const RealSet& rs1)
 {
@@ -645,4 +686,4 @@ goose_weighted_mean(const RealSet& rs, const RealSet& wt)
   return sum/wt.sum();
 }
 
-// $Id: descriptive.cpp,v 1.12 1999/07/09 19:49:13 trow Exp $
+// $Id: descriptive.cpp,v 1.15 1999/07/20 08:34:27 alstrup Exp $
