@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: descriptive.h,v 1.7 1999/07/09 19:44:50 trow Exp $
+// $Id: descriptive.h,v 1.9 1999/08/07 05:55:03 trow Exp $
 
 /* descriptive.h
  *
@@ -63,6 +63,8 @@ double goose_autocorr_z(const RealSet&, size_t lag);
 double goose_cramer_vos_mises(const RealSet&);
 double goose_anderson_darling(const RealSet&);
 double goose_gmean_threshold(const RealSet&, double c);
+double goose_mean_threshold_percentage(const RealSet&, double c);
+double goose_gmean_threshold_percentage(const RealSet&, double c);
 
 double goose_covar(const RealSet&, const RealSet&);
 double goose_corr(const RealSet&, const RealSet&);
@@ -86,7 +88,7 @@ double goose_weighted_mean(const RealSet&, const RealSet&);
 
 #endif // _INC_DESCRIPTIVE_H
 
-// $Id: descriptive.h,v 1.7 1999/07/09 19:44:50 trow Exp $
+// $Id: descriptive.h,v 1.9 1999/08/07 05:55:03 trow Exp $
 
 
 
