@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: Permutation.cpp,v 1.3 1999/07/07 05:07:43 trow Exp $
+// $Id: Permutation.cpp,v 1.4 1999/07/21 08:53:18 alstrup Exp $
 
 /* 
  * Permutation.cpp
@@ -64,9 +64,9 @@ Permutation::initialize(unsigned N, unsigned* d)
     
     // Throw if we are being fed something that isn't a
     // permutation on 0...(N-1)
-    if (d[i] < N)
+    if (d[i] >= N)
       throw Exception_IndexOutOfBounds(d[i],0,N-1);
-    if (! seen[d[i]])
+    if (seen[d[i]])
       throw Exception("Repeated value in permutation definition.");
     seen[d[i]] = 1;
     perm_.add(d[i]);
@@ -332,5 +332,5 @@ Permutation::calc_cycles() const
 }
 
 
-// $Id: Permutation.cpp,v 1.3 1999/07/07 05:07:43 trow Exp $
+// $Id: Permutation.cpp,v 1.4 1999/07/21 08:53:18 alstrup Exp $
 
