@@ -1,5 +1,5 @@
 // This is -*- C++ -*-
-// $Id: Permutation.h,v 1.3 1999/07/07 05:07:43 trow Exp $
+// $Id: Permutation.h,v 1.4 1999/07/15 17:44:13 trow Exp $
 
 /* 
  * Permutation.h
@@ -29,6 +29,7 @@
 
 #include "RCArray.h"
 #include "Random.h"
+#include "Exception.h"
 
 using namespace std;
 
@@ -84,6 +85,15 @@ public:
     }
   }
 
+  template<class X>
+  void permute(vector<X>& v) const {
+    if (size() != v.size())
+      throw Exception_SizesDoNotMatch();
+    // We assume that vector is implemented in one contiguous block of
+    // memory...
+    permute(&(v[0]));
+  }
+
   // some output that is useful for debugging (and not much else)
   void spew(ostream& out) const;
   void spew_cycles(ostream& out) const;
@@ -97,4 +107,4 @@ private:
 
 #endif // _INC_PERMUTATION_H
 
-// $Id: Permutation.h,v 1.3 1999/07/07 05:07:43 trow Exp $
+// $Id: Permutation.h,v 1.4 1999/07/15 17:44:13 trow Exp $
