@@ -1,11 +1,13 @@
 // This is -*- C++ -*-
-// $Id: test_A002.cpp,v 1.1 1999/07/07 05:05:45 trow Exp $
+// $Id: test_A002.cpp,v 1.2 1999/07/20 08:34:29 alstrup Exp $
 
 #include <config.h>
 #include <iostream>
 #include <math.h>
 #include <zdouble.h>
 
+using namespace std;
+
 const char* encoded[] = {
   "???????????",
   "??????o~??B",
@@ -52,10 +54,10 @@ main()
       cout << "failed";
     cout << endl;
   }
-   
+  return 0;   
 }
 
 
 
 
-// $Id: test_A002.cpp,v 1.1 1999/07/07 05:05:45 trow Exp $
+// $Id: test_A002.cpp,v 1.2 1999/07/20 08:34:29 alstrup Exp $
